# -*- coding: utf-8 -*-
## PloneiCalendar
## Store, share, and browse your iCalendar files in Plone
## Copyright (C)2006 Ingeniweb

## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.

## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program; see the file COPYING. If not, write to the
## Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.




from Products.PloneiCalendar.config import *
from Products.PloneiCalendar.Installation import Installation
from Products.PloneiCalendar.PloneiCalendarWorkflow import *
from Products.PloneiCalendar.PloneiCalendarTool import PloneiCalendarTool

from Products.CMFCore.WorkflowTool import addWorkflowFactory
from Products.CMFCore.CMFCorePermissions import *

from Products.CMFCore.utils import getToolByName
from cStringIO import StringIO


#product_name = "PloneiCalendar"

from Products.PloneiCalendar.config import *



def addRole(self, role, out):
    """
    Add the specified role to the portal's root
    """
    if not self._has_user_defined_role(role):
        self._addRole(role)
        out.write("%s role added.\n" % (role, ))

def setContentTypeRegistry(self, ):
    """
    Set the mime type and extension type of PloneiCalendar
    file.ics for extension
    text/calendar for mime type
    """
    ctr = getToolByName(self, 'content_type_registry')
    
    predicate_id = 'ics file'
    if not ctr.getPredicate(predicate_id):
        ctr.addPredicate( predicate_id, 'extension' )  
    ctr.getPredicate( predicate_id ).edit( extensions="ics" )
    ctr.assignTypeName( predicate_id, 'iCalendar' )
    #move top, it will be the first evaluate
    ctr.reorderPredicate(predicate_id, 0)

    predicate_id = 'calendar'
    if not ctr.getPredicate(predicate_id):
        ctr.addPredicate( predicate_id, 'major_minor' )
    ctr.getPredicate( predicate_id ).edit( major="text", minor="calendar" )
    ctr.assignTypeName( predicate_id, 'iCalendar' )
    #move top, it will be the second evaluate
    ctr.reorderPredicate(predicate_id, 1)

def install(self):
    installation = Installation(self)
    out = installation.out
    
    #Role (used in local roles)
    addRole(self, "LocalReader", out)
    addRole(self, "LocalWriter", out)
            
    installation.setPermissions(PERMS_LIST)
    
    # Archetypes import
    out.write('Archetypes Installation processing...\n')
    from Products.Archetypes import listTypes
    from Products.Archetypes.Extensions.utils import installTypes, install_subskin
    from Products.PloneiCalendar.content.iCalendar import iCalendar

    #AT install types
    typeInfo = listTypes(PROJECTNAME)
    out.write("typeInfo: \n%s\n" % typeInfo)
    installTypes(self, out, typeInfo, PROJECTNAME)
    out.write("Types installed.\n")
    
    #AT install skin
    install_subskin(self, out, GLOBALS)
    out.write("Skin installed.\n")
    
    # Add portal types to use portal factory
    pftool = getToolByName(self, 'portal_factory')
    pftool.manage_setPortalFactoryTypes(listOfTypeIds = ('iCalendar',))

    #addWorkflowFactory(createPloneicalendar_workflow, id='PloneiCalendar_workflow', title='PloneiCalendar Default Workflow')
    # Add workflow
    wtool = self.portal_workflow
    ploneicalendar_workflow_id = 'ploneicalendar_workflow'
    ploneicalendar_workflow = 'ploneicalendar_workflow (PloneiCalendar Default Workflow)'
    
    if ploneicalendar_workflow_id in wtool.objectIds():
        wtool._delObject(ploneicalendar_workflow_id)

    wtool.manage_addWorkflow(id=ploneicalendar_workflow_id, workflow_type=ploneicalendar_workflow)
    wtool.setChainForPortalTypes(('iCalendar',), ploneicalendar_workflow_id)
    setContentTypeRegistry(self, )

    addTool = self.manage_addProduct[PROJECTNAME].manage_addTool
    if not self.objectIds(spec=PloneiCalendarTool.meta_type):
        addTool(PloneiCalendarTool.meta_type)
        
    # Check that the tool has not been added using its id
    #if not hasattr(self, 'portal_ploneicalendar'):
    #  addTool = self.manage_addProduct['PloneiCalendar'].manage_addTool
      
    # Add the tool by its meta_type
    #  addTool('PloneiCalendar Tool')

    # Add the PloneiCalendar portlet to the portal
    ploneicalendar_slot='here/ploneicalendar_portlet/macros/portlet'
    if hasattr(self, "left_slots"):
        if ploneicalendar_slot in self.left_slots:
              installation.out.write("Left slot for PloneiCalendar already exists\n")
        else:
              left_slots_list=list(self.left_slots)
              self._delProperty('left_slots')
              left_slots_list.append(ploneicalendar_slot)
              self._setProperty('left_slots',tuple(left_slots_list),'lines')
              installation.out.write("Added left slot for PloneiCalendar\n")            
    
    return installation.report()
